==> com.liferay.frontend.editor.tinymce.web-4.0.5.jar: META-INF/resources/tiny_mce/langs/it.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('it', {
	Cut: 'Taglia',
	'Heading 5': 'Intestazione 5',
	'Header 2': 'Header 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		"Il tuo browser non supporta l'accesso diretto negli Appunti. Per favore usa i tasti di scelta rapida Ctrl+X/C/V.",
	'Heading 4': 'Intestazione 4',
	Div: 'Div',
	'Heading 2': 'Intestazione 2',
	Paste: 'Incolla',
	Close: 'Chiudi',
	'Font Family': 'Famiglia font',
	Pre: 'Pre',
	'Align right': 'Allinea a Destra',
	'New document': 'Nuovo Documento',
	Blockquote: 'Blockquote',
	'Numbered list': 'Elenchi Numerati',
	'Heading 1': 'Intestazione 1',
	Headings: 'Intestazioni',
	'Increase indent': 'Aumenta Rientro',
	Formats: 'Formattazioni',
	Headers: 'Intestazioni',
	'Select all': 'Seleziona Tutto',
	'Header 3': 'Intestazione 3',
	Blocks: 'Blocchi',
	Undo: 'Indietro',
	Strikethrough: 'Barrato',
	'Bullet list': 'Elenchi Puntati',
	'Header 1': 'Intestazione 1',
	Superscript: 'Apice',
	'Clear formatting': 'Cancella Formattazione',
	'Font Sizes': 'Dimensioni font',
	Subscript: 'Pedice',
	'Header 6': 'Intestazione 6',
	Redo: 'Ripeti',
	Paragraph: 'Paragrafo',
	Ok: 'Ok',
	Bold: 'Grassetto',
	Code: 'Codice',
	Italic: 'Corsivo',
	'Align center': 'Allinea al Cento',
	'Header 5': 'Intestazione 5',
	'Heading 6': 'Intestazione 6',
	'Heading 3': 'Intestazione 3',
	'Decrease indent': 'Riduci Rientro',
	'Header 4': 'Intestazione 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		"Incolla \u00e8 in modalit\u00e0 testo normale. I contenuti sono incollati come testo normale se non disattivi l'opzione.",
	Underline: 'Sottolineato',
	Cancel: 'Cancella',
	Justify: 'Giustifica',
	Inline: 'Inlinea',
	Copy: 'Copia',
	'Align left': 'Allinea a Sinistra',
	'Visual aids': 'Elementi Visivi',
	'Lower Greek': 'Greek Minore',
	Square: 'Quadrato',
	Default: 'Default',
	'Lower Alpha': 'Alpha Minore',
	Circle: 'Cerchio',
	Disc: 'Disco',
	'Upper Alpha': 'Alpha Superiore',
	'Upper Roman': 'Roman Superiore',
	'Lower Roman': 'Roman Minore',
	Name: 'Nome',
	Anchor: 'Fissa',
	'You have unsaved changes are you sure you want to navigate away?':
		'Non hai salvato delle modifiche, sei sicuro di andartene?',
	'Restore last draft': "Ripristina l'ultima bozza.",
	'Special character': 'Carattere Speciale',
	'Source code': 'Codice Sorgente',
	Color: 'Colore',
	'Right to left': 'Da Destra a Sinistra',
	'Left to right': 'Da Sinistra a Destra',
	Emoticons: 'Emoction',
	Robots: 'Robot',
	'Document properties': 'Propriet\u00e0 Documento',
	Title: 'Titolo',
	Keywords: 'Parola Chiave',
	Encoding: 'Codifica',
	Description: 'Descrizione',
	Author: 'Autore',
	Fullscreen: 'Schermo Intero',
	'Horizontal line': 'Linea Orizzontale',
	'Horizontal space': 'Spazio Orizzontale',
	'Insert/edit image': 'Aggiungi/Modifica Immagine',
	General: 'Generale',
	Advanced: 'Avanzato',
	Source: 'Fonte',
	Border: 'Bordo',
	'Constrain proportions': 'Mantieni Proporzioni',
	'Vertical space': 'Spazio Verticale',
	'Image description': 'Descrizione Immagine',
	Style: 'Stile',
	Dimensions: 'Dimenzioni',
	'Insert image': 'Inserisci immagine',
	'Insert date/time': 'Inserisci Data/Ora',
	'Remove link': 'Rimuovi link',
	Url: 'Url',
	'Text to display': 'Testo da Visualizzare',
	Anchors: 'Anchors',
	'Insert link': 'Inserisci il Link',
	'New window': 'Nuova Finestra',
	None: 'No',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		"L'URL inserito sembra essere un collegamento esterno. Vuoi aggiungere il prefisso necessario http://?",
	Target: 'Target',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		"L'URL inserito sembra essere un indirizzo email. Vuoi aggiungere il prefisso necessario mailto:?",
	'Insert/edit link': 'Inserisci/Modifica Link',
	'Insert/edit video': 'Inserisci/Modifica Video',
	Poster: 'Anteprima',
	'Alternative source': 'Alternativo',
	'Paste your embed code below:': "Incolla il codice d'incorporamento qui:",
	'Insert video': 'Inserisci Video',
	Embed: 'Incorporare',
	'Nonbreaking space': 'Spazio unificatore',
	'Page break': 'Interruzione di pagina',
	'Paste as text': 'incolla come testo',
	Preview: 'Anteprima',
	Print: 'Stampa',
	Save: 'Salva',
	'Could not find the specified string.':
		'Impossibile trovare la parola specifica.',
	Replace: 'Sostituisci',
	Next: 'Successivo',
	'Whole words': 'Parole Sbagliate',
	'Find and replace': 'Trova e Sostituisci',
	'Replace with': 'Sostituisci Con',
	Find: 'Trova',
	'Replace all': 'Sostituisci Tutto',
	'Match case': 'Maiuscole/Minuscole ',
	Prev: 'Precedente',
	Spellcheck: 'Controllo ortografico',
	Finish: 'Termina',
	'Ignore all': 'Ignora Tutto',
	Ignore: 'Ignora',
	'Add to Dictionary': 'Aggiungi al Dizionario',
	'Insert row before': 'Inserisci una Riga Prima',
	Rows: 'Righe',
	Height: 'Altezza',
	'Paste row after': 'Incolla una Riga Dopo',
	Alignment: 'Allineamento',
	'Border color': 'Colore bordo',
	'Column group': 'Gruppo di Colonne',
	Row: 'Riga',
	'Insert column before': 'Inserisci una Colonna Prima',
	'Split cell': 'Dividi Cella',
	'Cell padding': 'Padding della Cella',
	'Cell spacing': 'Spaziatura della Cella',
	'Row type': 'Tipo di Riga',
	'Insert table': 'Inserisci Tabella',
	Body: 'Body',
	Caption: 'Didascalia',
	Footer: 'Footer',
	'Delete row': 'Cancella Riga',
	'Paste row before': 'Incolla una Riga Prima',
	Scope: 'Campo',
	'Delete table': 'Cancella Tabella',
	'H Align': 'Allineamento H',
	Top: 'In alto',
	'Header cell': "cella d'intestazione",
	Column: 'Colonna',
	'Row group': 'Gruppo di Righe',
	Cell: 'Cella',
	Middle: 'In mezzo',
	'Cell type': 'Tipo di Cella',
	'Copy row': 'Copia Riga',
	'Row properties': 'Propriet\u00e0 della Riga',
	'Table properties': 'Propiet\u00e0 della Tabella',
	Bottom: 'In fondo',
	'V Align': 'Allineamento V',
	Header: 'Header',
	Right: 'Destra',
	'Insert column after': 'Inserisci una Colonna Dopo',
	Cols: 'Colonne',
	'Insert row after': 'Inserisci una Riga Dopo',
	Width: 'Larghezza',
	'Cell properties': 'Propiet\u00e0 della Cella',
	Left: 'Sinistra',
	'Cut row': 'Taglia Riga',
	'Delete column': 'Cancella Colonna',
	Center: 'Centro',
	'Merge cells': 'Unisci Cella',
	'Insert template': 'Inserisci Template',
	Templates: 'Template',
	'Background color': 'Colore Background',
	'Custom...': 'Personalizzato...',
	'Custom color': 'Colore personalizzato',
	'No color': 'Nessun colore',
	'Text color': 'Colore Testo',
	'Show blocks': 'Mostra Blocchi',
	'Show invisible characters': 'Mostra Caratteri Invisibili',
	'Words: {0}': 'Parole: {0}',
	Insert: 'Inserisci',
	File: 'File',
	Edit: 'Modifica',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		"Rich Text Area. Premi ALT-F9 per il men\u00f9. Premi ALT-F10 per la barra degli strumenti. Premi ALT-0 per l'aiuto.",
	Tools: 'Strumenti',
	View: 'Visualiza',
	Table: 'Tabella',
	Format: 'Formato',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/tiny_mce/langs/it.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('it', {
	'Cut': 'Taglia',
	'Heading 5': 'Intestazione 5',
	'Header 2': 'Header 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		"Il tuo browser non supporta l'accesso diretto negli Appunti. Per favore usa i tasti di scelta rapida Ctrl+X/C/V.",
	'Heading 4': 'Intestazione 4',
	'Div': 'Div',
	'Heading 2': 'Intestazione 2',
	'Paste': 'Incolla',
	'Close': 'Chiudi',
	'Font Family': 'Famiglia font',
	'Pre': 'Pre',
	'Align right': 'Allinea a Destra',
	'New document': 'Nuovo Documento',
	'Blockquote': 'Blockquote',
	'Numbered list': 'Elenchi Numerati',
	'Heading 1': 'Intestazione 1',
	'Headings': 'Intestazioni',
	'Increase indent': 'Aumenta Rientro',
	'Formats': 'Formattazioni',
	'Headers': 'Intestazioni',
	'Select all': 'Seleziona Tutto',
	'Header 3': 'Intestazione 3',
	'Blocks': 'Blocchi',
	'Undo': 'Indietro',
	'Strikethrough': 'Barrato',
	'Bullet list': 'Elenchi Puntati',
	'Header 1': 'Intestazione 1',
	'Superscript': 'Apice',
	'Clear formatting': 'Cancella Formattazione',
	'Font Sizes': 'Dimensioni font',
	'Subscript': 'Pedice',
	'Header 6': 'Intestazione 6',
	'Redo': 'Ripeti',
	'Paragraph': 'Paragrafo',
	'Ok': 'Ok',
	'Bold': 'Grassetto',
	'Code': 'Codice',
	'Italic': 'Corsivo',
	'Align center': 'Allinea al Cento',
	'Header 5': 'Intestazione 5',
	'Heading 6': 'Intestazione 6',
	'Heading 3': 'Intestazione 3',
	'Decrease indent': 'Riduci Rientro',
	'Header 4': 'Intestazione 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		"Incolla \u00e8 in modalit\u00e0 testo normale. I contenuti sono incollati come testo normale se non disattivi l'opzione.",
	'Underline': 'Sottolineato',
	'Cancel': 'Cancella',
	'Justify': 'Giustifica',
	'Inline': 'Inlinea',
	'Copy': 'Copia',
	'Align left': 'Allinea a Sinistra',
	'Visual aids': 'Elementi Visivi',
	'Lower Greek': 'Greek Minore',
	'Square': 'Quadrato',
	'Default': 'Default',
	'Lower Alpha': 'Alpha Minore',
	'Circle': 'Cerchio',
	'Disc': 'Disco',
	'Upper Alpha': 'Alpha Superiore',
	'Upper Roman': 'Roman Superiore',
	'Lower Roman': 'Roman Minore',
	'Name': 'Nome',
	'Anchor': 'Fissa',
	'You have unsaved changes are you sure you want to navigate away?':
		'Non hai salvato delle modifiche, sei sicuro di andartene?',
	'Restore last draft': "Ripristina l'ultima bozza.",
	'Special character': 'Carattere Speciale',
	'Source code': 'Codice Sorgente',
	'Color': 'Colore',
	'Right to left': 'Da Destra a Sinistra',
	'Left to right': 'Da Sinistra a Destra',
	'Emoticons': 'Emoction',
	'Robots': 'Robot',
	'Document properties': 'Propriet\u00e0 Documento',
	'Title': 'Titolo',
	'Keywords': 'Parola Chiave',
	'Encoding': 'Codifica',
	'Description': 'Descrizione',
	'Author': 'Autore',
	'Fullscreen': 'Schermo Intero',
	'Horizontal line': 'Linea Orizzontale',
	'Horizontal space': 'Spazio Orizzontale',
	'Insert/edit image': 'Aggiungi/Modifica Immagine',
	'General': 'Generale',
	'Advanced': 'Avanzato',
	'Source': 'Fonte',
	'Border': 'Bordo',
	'Constrain proportions': 'Mantieni Proporzioni',
	'Vertical space': 'Spazio Verticale',
	'Image description': 'Descrizione Immagine',
	'Style': 'Stile',
	'Dimensions': 'Dimenzioni',
	'Insert image': 'Inserisci immagine',
	'Insert date/time': 'Inserisci Data/Ora',
	'Remove link': 'Rimuovi link',
	'Url': 'Url',
	'Text to display': 'Testo da Visualizzare',
	'Anchors': 'Anchors',
	'Insert link': 'Inserisci il Link',
	'New window': 'Nuova Finestra',
	'None': 'No',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		"L'URL inserito sembra essere un collegamento esterno. Vuoi aggiungere il prefisso necessario http://?",
	'Target': 'Target',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		"L'URL inserito sembra essere un indirizzo email. Vuoi aggiungere il prefisso necessario mailto:?",
	'Insert/edit link': 'Inserisci/Modifica Link',
	'Insert/edit video': 'Inserisci/Modifica Video',
	'Poster': 'Anteprima',
	'Alternative source': 'Alternativo',
	'Paste your embed code below:': "Incolla il codice d'incorporamento qui:",
	'Insert video': 'Inserisci Video',
	'Embed': 'Incorporare',
	'Nonbreaking space': 'Spazio unificatore',
	'Page break': 'Interruzione di pagina',
	'Paste as text': 'incolla come testo',
	'Preview': 'Anteprima',
	'Print': 'Stampa',
	'Save': 'Salva',
	'Could not find the specified string.':
		'Impossibile trovare la parola specifica.',
	'Replace': 'Sostituisci',
	'Next': 'Successivo',
	'Whole words': 'Parole Sbagliate',
	'Find and replace': 'Trova e Sostituisci',
	'Replace with': 'Sostituisci Con',
	'Find': 'Trova',
	'Replace all': 'Sostituisci Tutto',
	'Match case': 'Maiuscole/Minuscole ',
	'Prev': 'Precedente',
	'Spellcheck': 'Controllo ortografico',
	'Finish': 'Termina',
	'Ignore all': 'Ignora Tutto',
	'Ignore': 'Ignora',
	'Add to Dictionary': 'Aggiungi al Dizionario',
	'Insert row before': 'Inserisci una Riga Prima',
	'Rows': 'Righe',
	'Height': 'Altezza',
	'Paste row after': 'Incolla una Riga Dopo',
	'Alignment': 'Allineamento',
	'Border color': 'Colore bordo',
	'Column group': 'Gruppo di Colonne',
	'Row': 'Riga',
	'Insert column before': 'Inserisci una Colonna Prima',
	'Split cell': 'Dividi Cella',
	'Cell padding': 'Padding della Cella',
	'Cell spacing': 'Spaziatura della Cella',
	'Row type': 'Tipo di Riga',
	'Insert table': 'Inserisci Tabella',
	'Body': 'Body',
	'Caption': 'Didascalia',
	'Footer': 'Footer',
	'Delete row': 'Cancella Riga',
	'Paste row before': 'Incolla una Riga Prima',
	'Scope': 'Campo',
	'Delete table': 'Cancella Tabella',
	'H Align': 'Allineamento H',
	'Top': 'In alto',
	'Header cell': "cella d'intestazione",
	'Column': 'Colonna',
	'Row group': 'Gruppo di Righe',
	'Cell': 'Cella',
	'Middle': 'In mezzo',
	'Cell type': 'Tipo di Cella',
	'Copy row': 'Copia Riga',
	'Row properties': 'Propriet\u00e0 della Riga',
	'Table properties': 'Propiet\u00e0 della Tabella',
	'Bottom': 'In fondo',
	'V Align': 'Allineamento V',
	'Header': 'Header',
	'Right': 'Destra',
	'Insert column after': 'Inserisci una Colonna Dopo',
	'Cols': 'Colonne',
	'Insert row after': 'Inserisci una Riga Dopo',
	'Width': 'Larghezza',
	'Cell properties': 'Propiet\u00e0 della Cella',
	'Left': 'Sinistra',
	'Cut row': 'Taglia Riga',
	'Delete column': 'Cancella Colonna',
	'Center': 'Centro',
	'Merge cells': 'Unisci Cella',
	'Insert template': 'Inserisci Template',
	'Templates': 'Template',
	'Background color': 'Colore Background',
	'Custom...': 'Personalizzato...',
	'Custom color': 'Colore personalizzato',
	'No color': 'Nessun colore',
	'Text color': 'Colore Testo',
	'Show blocks': 'Mostra Blocchi',
	'Show invisible characters': 'Mostra Caratteri Invisibili',
	'Words: {0}': 'Parole: {0}',
	'Insert': 'Inserisci',
	'File': 'File',
	'Edit': 'Modifica',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		"Rich Text Area. Premi ALT-F9 per il men\u00f9. Premi ALT-F10 per la barra degli strumenti. Premi ALT-0 per l'aiuto.",
	'Tools': 'Strumenti',
	'View': 'Visualiza',
	'Table': 'Tabella',
	'Format': 'Formato',
});
